@@ -27,15 +27,15 @@ class Connector(connector.SQLConnector):
                 cursor.execute(sql)
                 return [dict(row) for row in cursor.fetchall()]
 
-    def _export(self, query, fmt, row_limit=None):
+    def _export(self, query, fmt, row_limit):
         if fmt == formats.CSV:
-            return self._export_to_csv(query)
+            return self._export_to_csv(query, row_limit)
         if fmt == formats.NDJSON:
-            return self._export_to_ndjson(query)
+            return self._export_to_ndjson(query, row_limit)
         raise errors.UnsupportedFormatError(fmt)
 
     # https://www.postgresql.org/docs/14/sql-copy.html.
-    def _export_to_csv(self, query, row_limit=None):
+    def _export_to_csv(self, query, row_limit):
         tmp = self._binary_tempfile(extension='csv')
         with psycopg2.connect() as connection:
             with connection.cursor() as cursor:
@@ -46,7 +46,7 @@ class Connector(connector.SQLConnector):
     # This is not implemented with row_to_json() and COPY ... TO because COPY
     # escapes backlashes. So, for example, a string column that contained JSON
     # would have quotes escaped incorrectly. Instead of \", you'd get \\".
-    def _export_to_ndjson(self, query, row_limit=None):
+    def _export_to_ndjson(self, query, row_limit):
         with psycopg2.connect() as connection:
             with connection.cursor(cursor_factory=psycopg2.extras.RealDictCursor) as cursor:
                 cursor.execute(query)
