@@ -48,8 +48,8 @@ class Connector(connector.SQLConnector):
     # as the method is not part of the generic Connector's interface, and the CDK user will become coupled to a concrete Connector implementation.
     def get_roles(self):
         roles = []
-        for role in list(self._query('show roles')):
-            roles.append(Role(name=role['name'], value=role['name']))
+        for role in list(self._query(f"show grants to user {config.get('SF_USER')}")):
+            roles.append(Role(name=role['role'], value=role['role']))
         roles.sort(key=lambda role: role.name)
         return roles
         
